CHANGELOG
=========

0.6.0
----------

Feature
+++++++

- Added `get_port` helper that can randomly select open port out of given set, or range-tuple
- Added type annotations and compatibility with PEP 561
- Support only python 3.7 and up
